#!/usr/bin/env perl

#:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
# This file is part of G-language Genome Analysis Environment package
#
#     Copyright (C) 2001 - 2002 Keio University
#:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
# 
#   $Id: Operon.pm,v 1.1.1.1 2002/04/02 20:25:42 gaou Exp $
#
# G-language GAE is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# G-language GAE is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public
# License along with G-language GAE -- see the file COPYING.
# If not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
# 
#END_HEADER
#


package G::Seq::Operon;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
use G::Messenger;
use SubOpt;

require Exporter;

@ISA = qw(Exporter AutoLoader);
@EXPORT = qw(
	     new
	     set_operon
);
$VERSION = '1.0';



######################################
#         Main Methods               #
######################################

sub new {
    my $this = shift;

    return $this;
}

# set_operon ver. 20020207-01
# Author: Kazuharu Arakawa

sub set_operon {
    my @args = opt_get(@_);
    my $gb = shift @args;

    if ($gb->{LOCUS}->{id} eq 'U00096'){

       my %op = (
	      "b1213", "kdsA", "flhB", "flhBA", "araH_1", "araFGH", "nuoC", "nuo", 
	      "glcF", "glc", "yhbJ", "rpoN", "mhpA", "mhp", "mhpC", "mhp", 
	      "mhpD", "mhp", "mhpE", "mhp", "b4103", "phn", "ylcA", "copRS", 
	      "ybcZ", "copRS", "accA", "lpx", "accB", "accBC", "accC", "accBC", 
	      "accD", "hisT", "aceA", "ace", "aceB", "ace", "aceE", "aceEF", 
	      "aceF", "aceEF", "aceK", "ace", "ackA", "ackA-pta", "acpP", "fabDGacpP", 
	      "acpS", "pdxJ", "acrA", "acrAB", "acrB", "acrAB", "acrE", "acrEF", 
	      "acrF", "acrEF", "ada", "ada-alkB", "agaA", "aga", "agaB", "aga", 
	      "agaC", "aga", "agaD", "aga", "agaI", "aga", "agaS", "aga", 
	      "agaV", "aga", "agaW", "aga", "agaY", "aga", "agaZ", "aga", 
	      "alkB", "ada-alkB", "amiA", "amiAhemF", "amiB", "amiB", "ampD", "ampDE", 
	      "ampE", "ampDE", "apaG", "surA-pdxA-ksgA-apaGH", "apaH", "surA-pdxA-ksgA-apaGH", "appA", "appCBA", 
	      "appB", "appCBA", "appC", "appCBA", "araA", "araBAD", "araB", "araBAD", 
	      "araD", "araBAD", "araG", "araFGH", "araH_2", "araFGH", "argB", "argECBH", 
	      "argC", "argECBH", "argH", "argECBH", "aroB", "dam", "aroF", "tyr", 
	      "aroK", "dam", "arsB", "arsBC", "arsC", "arsBC", "arsR", "arsBC", 
	      "artI", "artPIQMJ", "artJ", "artPIQMJ", "artM", "artPIQMJ", "artP", "artPIQMJ", 
	      "artQ", "artPIQMJ", "ascB", "ascFB", "ascF", "ascFB", "atoA", "atoDAB", 
	      "atoB", "atoDAB", "atoC", "atoSC", "atoD", "atoDAB", "atoS", "atoSC", 
	      "atpA", "atp", "atpB", "atp", "atpC", "atp", "atpD", "atp", 
	      "atpE", "atp", "atpF", "atp", "atpG", "atp", "atpH", "atp", 
	      "atpI", "atp", "baeR", "baeSR", "baeS", "baeSR", "basR", "basRS", 
	      "basS", "basRS", "bglB", "bglGFB", "bglF", "bglGFB", "bglG", "bglGFB", 
	      "bioB", "bioBFCD", "bioC", "bioBFCD", "bioD", "bioBFCD", "bioF", "bioBFCD", 
	      "btuC", "btuCED", "btuD", "btuCED", "btuE", "btuCED", "cadA", "cad", 
	      "cadB", "cad", "caiA", "cai", "caiB", "cai", "caiC", "cai", 
	      "caiD", "cai", "caiE", "cai", "caiT", "cai", "carA", "carAB", 
	      "carB", "carAB", "ccmA", "ccmABCDEFGH", "ccmB", "ccmABCDEFGH", "ccmC", "ccmABCDEFGH", 
	      "ccmD", "ccmABCDEFGH", "ccmE", "ccmABCDEFGH", "ccmF", "ccmABCDEFGH", "ccmH", "ccmABCDEFGH", 
	      "celA", "celABCDF", "celB", "celABCDF", "celC", "celABCDF", "celD", "celABCDF", 
	      "celF", "celABCDF", "cheA", "motABcheAW", "cheB", "cheRBYZ", "cheR", "cheRBYZ", 
	      "cheW", "motABcheAW", "cheY", "cheRBYZ", "cheZ", "cheRBYZ", "chpA", "relA", 
	      "chpB", "chpSB", "chpR", "relA", "chpS", "chpSB", "clpP", "clpPX", 
	      "clpX", "clpPX", "cmk", "rpsA", "cobS", "cobUST", "cobT", "cobUST", 
	      "cobU", "cobUST", "codA", "codBA", "codB", "codBA", "cpxA", "cpxAR", 
	      "cpxR", "cpxAR", "creA", "creABCD", "creB", "creABCD", "creC", "creABCD", 
	      "creD", "creABCD", "crr", "pts", "csgA", "csgBA", "csgB", "csgBA", 
	      "csgD", "csgDEFG", "csgE", "csgDEFG", "csgF", "csgDEFG", "csgG", "csgDEFG", 
	      "cvpA", "purF", "cydA", "cyd", "cydB", "cyd", "cynS", "cynTSX", 
	      "cynT", "cynTSX", "cynX", "cynTSX", "cyoA", "cyoABCDE", "cyoB", "cyoABCDE", 
	      "cyoC", "cyoABCDE", "cyoD", "cyoABCDE", "cyoE", "cyoABCDE", "cysA", "cysPTWAM", 
	      "cysC", "cysDNC", "cysD", "cysDNC", "cysH", "cysJIH", "cysI", "cysJIH", 
	      "cysJ", "cysJIH", "cysM", "cysPTWAM", "cysN", "cysDNC", "cysP", "cysPTWAM", 
	      "cysU", "cysPTWAM", "cysW", "cysPTWAM", "dadA", "dadAX", "dadX", "dadAX", 
	      "dam", "dam", "damX", "dam", "dapA", "dapAnlp", "dcd", "dcd", 
	      "dcm", "dcm-vsr", "ddlB", "murGC", "dedA", "hisT", "dedD", "dedCD", 
	      "def", "def-fmt", "deoA", "deoAB", "deoB", "deoAB", "deoC", "deoAB", 
	      "deoD", "deoAB", "dfp", "dfp-dut", "dicB", "dicB", "dmsA", "dmsABC", 
	      "dmsB", "dmsABC", "dmsC", "dmsABC", "dnaA", "dnaA", "dnaC", "dnaTC", 
	      "dnaE", "lpx", "dnaG", "rpsU-dnaG-rpoD", "dnaJ", "dnaK", "dnaK", "dnaK", 
	      "dnaN", "dnaA", "dnaT", "dnaTC", "dppA", "dpp", "dppB", "dpp", 
	      "dppC", "dpp", "dppD", "dpp", "dppF", "dpp", "dsbE", "ccmABCDEFGH", 
	      "dsdA", "dsdXA", "dsdX", "dsdXA", "dut", "dfp-dut", "ebgA", "ebgAC", 
	      "ebgC", "ebgAC", "ecpD", "htrE", "eda", "edd-eda", "edd", "edd-eda", 
	      "entA", "entCEBA", "entB", "entCEBA", "entC", "entCEBA", "entE", "entCEBA", 
	      "envZ", "ompB", "era", "rnc", "fabD", "fabDGacpP", "fabG", "fabDGacpP", 
	      "fabZ", "lpx", "fadA", "fadBA", "fadB", "fadBA", "fdnG", "fdnGHI", 
	      "fdnH", "fdnGHI", "fdnI", "fdnGHI", "fecA", "fecABCDE", "fecB", "fecABCDE", 
	      "fecC", "fecABCDE", "fecD", "fecABCDE", "fecE", "fecABCDE", "feoA", "feoAB", 
	      "feoB", "feoAB", "fepC", "fepDGC", "fepD", "fepDGC", "fepG", "fepDGC", 
	      "fhuA", "fhuACDB", "fhuB", "fhuACDB", "fhuC", "fhuACDB", "fhuD", "fhuACDB", 
	      "fic", "fic-pabA", "fis", "fis", "fixA", "fix", "fixB", "fix", 
	      "fixC", "fix", "flgA", "flgAMN", "flgB", "flgBCDEFGHI", "flgC", "flgBCDEFGHI", 
	      "flgD", "flgBCDEFGHI", "flgE", "flgBCDEFGHI", "flgF", "flgBCDEFGHI", "flgG", "flgBCDEFGHI", 
	      "flgH", "flgBCDEFGHI", "flgI", "flgBCDEFGHI", "flgK", "flgKL", "flgL", "flgKL", 
	      "flgM", "flgAMN", "flgN", "flgAMN", "flhA", "flhBA", "flhC", "flhDC", 
	      "flhD", "flhDC", "fliA", "fliAZY", "fliD", "fliDST", "fliF", "fliFGHIJK", 
	      "fliG", "fliFGHIJK", "fliH", "fliFGHIJK", "fliI", "fliFGHIJK", "fliJ", "fliFGHIJK", 
	      "fliK", "fliFGHIJK", "fliL", "fliLMNOPQR", "fliM", "fliLMNOPQR", "fliN", "fliLMNOPQR", 
	      "fliO", "fliLMNOPQR", "fliP", "fliLMNOPQR", "fliQ", "fliLMNOPQR", "fliR", "fliLMNOPQR", 
	      "fliS", "fliDST", "fliT", "fliDST", "fliY", "fliAZY", "fliZ", "fliAZY", 
	      "fmt", "def-fmt", "fmu", "def-fmt", "folC", "dedCD", "frdA", "frd", 
	      "frdB", "frd", "frdC", "frd", "frdD", "frd", "frr", "rpsB", 
	      "fruA", "fru", "fruB", "fru", "fruK", "fru", "frvA", "frv", 
	      "frvB", "frv", "frvX", "frv", "ftsE", "ftsYEX", "ftsX", "ftsYEX", 
	      "ftsY", "ftsYEX", "fucA", "fucAO", "fucI", "fucPIK", "fucK", "fucPIK", 
	      "fucO", "fucAO", "fucP", "fucPIK", "fucR", "fucPIK", "fucU", "fucPIK", 
	      "fusA", "str", "galE", "gal", "galK", "gal", "galM", "gal", 
	      "galT", "gal", "gatA", "gat", "gatB", "gat", "gatC", "gat", 
	      "gatD", "gat", "gatY", "gat", "gatZ", "gat", "gcvH", "gcv", 
	      "gcvP", "gcv", "gcvT", "gcv", "glcB", "glc", "glcD", "glc", 
	      "glcG", "glc", "glgA", "glgBXCAP", "glgB", "glgBXCAP", "glgC", "glgBXCAP", 
	      "glgP", "glgBXCAP", "glgX", "glgBXCAP", "glmS", "glmUS", "glmU", "glmUS", 
	      "glnA", "glnALG", "glnG", "glnALG", "glnH", "glnHPQ", "glnL", "glnALG", 
	      "glnP", "glnHPQ", "glnQ", "glnHPQ", "glpA", "glpABC", "glpB", "glpABC", 
	      "glpC", "glpABC", "glpF", "glpFK", "glpK", "glpFK", "glpQ", "glpTQ", 
	      "glpT", "glpTQ", "gltB", "gltBDF", "gltD", "gltBDF", "gltF", "gltBDF", 
	      "gltJ", "gltJKL", "gltK", "gltJKL", "gltL", "gltJKL", "glvB", "glvCBG", 
	      "glvC", "glvCBG", "glvG", "glvCBG", "glyQ", "glyQS", "glyS", "glyQS", 
	      "gmk", "spoT", "gntK", "gntKU", "gph", "dam", "guaA", "guaBA", 
	      "guaB", "guaBA", "gusC", "uidABC", "gutM", "srlABD", "gutQ", "srlABD", 
	      "hemA", "kdsA", "hemC", "hem", "hemD", "hem", "hemF", "amiAhemF", 
	      "hemK", "kdsA", "hemX", "hem", "hemY", "hem", "hflC", "hflA", 
	      "hflK", "hflA", "hflX", "hflA", "hfq", "amiB", "hipA", "hip", 
	      "hipB", "hip", "hisA", "hisGDCBHAFE", "hisB", "hisGDCBHAFE", "hisC", "hisGDCBHAFE", 
	      "hisD", "hisGDCBHAFE", "hisF", "hisGDCBHAFE", "hisG", "hisGDCBHAFE", "hisH", "hisGDCBHAFE", 
	      "hisI", "hisGDCBHAFE", "hisM", "hisMP", "htrE", "htrE", "hyaA", "hya", 
	      "hyaB", "hya", "hyaC", "hya", "hyaD", "hya", "hyaE", "hya", 
	      "hyaF", "hya", "hybA", "hyb", "hybB", "hyb", "hybC", "hyb", 
	      "hybD", "hyb", "hybE", "hyb", "hybF", "hyb", "hybG", "hyb", 
	      "hycA", "hyc", "hycB", "hyc", "hycC", "hyc", "hycD", "hyc", 
	      "hycE", "hyc", "hycF", "hyc", "hycG", "hyc", "hycH", "hyc", 
	      "hydG", "hydHG", "hydH", "hydHG", "hypA", "hypABCDE", "hypB", "hypABCDE", 
	      "hypC", "hypABCDE", "hypD", "hypABCDE", "hypE", "hypABCDE", "ileS", "ileS-lsp", 
	      "ilvA", "ilvGMEDA", "ilvB", "ilvBN", "ilvD", "ilvGMEDA", "ilvE", "ilvGMEDA", 
	      "ilvH", "ilvIH", "ilvI", "ilvIH", "ilvM", "ilvGMEDA", "ilvN", "ilvBN", 
	      "infB", "nusA", "kbl", "tdh", "kdpA", "kdpABC", "kdpB", "kdpABC", 
	      "kdpC", "kdpABC", "kdpD", "kdpABC", "kdpE", "kdpABC", "kdtA", "kdtAB", 
	      "kdtB", "kdtAB", "ksgA", "surA-pdxA-ksgA-apaGH", "lacA", "lac", "lacY", "lac", 
	      "lacZ", "lac", "lamB", "malK-lamB", "lctD", "lct", "lctR", "lct", 
	      "lepA", "lepAB", "lepB", "lepAB", "leuA", "leu", "leuB", "leu", 
	      "leuC", "leu", "leuD", "leu", "livF", "livKHMGF", "livG", "livKHMGF", 
	      "livH", "livKHMGF", "livK", "livKHMGF", "livM", "livKHMGF", "lldP", "lct", 
	      "lpdA", "aceEF", "lpxA", "lpx", "lpxB", "lpx", "lpxD", "lpx", 
	      "lspA", "ileS-lsp", "lysS", "prfBlysS", "malE", "malEFG", "malF", "malEFG", 
	      "malG", "malEFG", "malK", "malK-lamB", "malM", "malK-lamB", "malP", "malPQ", 
	      "malQ", "malPQ", "malX", "malXY", "malY", "malXY", "manX", "manXYZ", 
	      "manY", "manXYZ", "manZ", "manXYZ", "marA", "marRAB", "marB", "marRAB", 
	      "marR", "marRAB", "mazG", "relA", "mdoG", "mdoGH", "mdoH", "mdoGH", 
	      "melA", "melAB", "melB", "melAB", "menB", "menFDBCE", "menC", "menFDBCE", 
	      "menD", "menFDBCE", "menE", "menFDBCE", "menF", "menFDBCE", "metB", "metBL", 
	      "metL", "metBL", "mglA", "mglBA", "mglB", "mglBA", "mglC", "mglBA", 
	      "mhpB", "mhp", "mhpF", "mhp", "miaA", "amiB", "moaA", "moaABCDE", 
	      "moaB", "moaABCDE", "moaC", "moaABCDE", "moaD", "moaABCDE", "moaE", "moaABCDE", 
	      "modA", "modABC", "modB", "modABC", "modC", "modABC", "moeA", "moeAB", 
	      "moeB", "moeAB", "mopA", "groE", "mopB", "groE", "motA", "motABcheAW", 
	      "motB", "motABcheAW", "mrdA", "mrdAB", "mrdB", "mrdAB", "mtlA", "mtlAD", 
	      "mtlD", "mtlAD", "mukB", "smtAmukFEB", "mukE", "smtAmukFEB", "mukF", "smtAmukFEB", 
	      "murC", "murGC", "murG", "murGC", "mutL", "amiB", "nagA", "nagBACD", 
	      "nagB", "nagBACD", "nagC", "nagBACD", "nagD", "nagBACD", "napA", "napAGHBC", 
	      "napB", "napAGHBC", "napC", "napAGHBC", "napG", "napAGHBC", "napH", "napAGHBC", 
	      "narG", "narGHJI", "narH", "narGHJI", "narI", "narGHJI", "narJ", "narGHJI", 
	      "narL", "narXL", "narV", "narZYWV", "narW", "narZYWV", "narX", "narXL", 
	      "narY", "narZYWV", "narZ", "narZYWV", "nikA", "nikABCDE", "nikB", "nikABCDE", 
	      "nikC", "nikABCDE", "nikD", "nikABCDE", "nikE", "nikABCDE", "nirB", "nirBDC", 
	      "nirC", "nirBDC", "nirD", "nirBDC", "nlpB", "dapAnlp", "nrdA", "nrdAB", 
	      "nrdB", "nrdAB", "nrdE", "nrdEF", "nrdF", "nrdEF", "nrfA", "nrf", 
	      "nrfB", "nrf", "nrfC", "nrf", "nrfD", "nrf", "nrfE", "nrf", 
	      "nrfF", "nrf", "nrfG", "nrf", "nuoA", "nuo", "nuoB", "nuo", 
	      "nuoE", "nuo", "nuoF", "nuo", "nuoG", "nuo", "nuoH", "nuo", 
	      "nuoI", "nuo", "nuoJ", "nuo", "nuoK", "nuo", "nuoL", "nuo", 
	      "nuoM", "nuo", "nuoN", "nuo", "nusA", "nusA", "nusG", "secE-nusG", 
	      "ompR", "ompB", "oppA", "oppABCDF", "oppB", "oppABCDF", "oppC", "oppABCDF", 
	      "oppD", "oppABCDF", "oppF", "oppABCDF", "otsA", "otsBA", "otsB", "otsBA", 
	      "pabA", "fic-pabA", "panF", "prmA", "pdxA", "surA-pdxA-ksgA-apaGH", "pdxB", "hisT", 
	      "pdxH", "pdxH-tyrS", "pdxJ", "pdxJ", "pheS", "pheST", "pheT", "pheST", 
	      "phnC", "phn", "phnD", "phn", "phnE", "phn", "phnF", "phn", 
	      "phnG", "phn", "phnH", "phn", "phnI", "phn", "phnJ", "phn", 
	      "phnK", "phn", "phnL", "phn", "phnM", "phn", "phnN", "phn", 
	      "phnO", "phn", "phnP", "phn", "phnQ", "phn", "phoB", "phoBR", 
	      "phoP", "phoPQ", "phoQ", "phoPQ", "phoR", "phoBR", "pnp", "rpsO-pnp", 
	      "potE", "speFpotE", "potF", "potFGHI", "potG", "potFGHI", "potH", "potFGHI", 
	      "potI", "potFGHI", "ppk", "ppx", "ppx", "ppx", "pqiA", "pqiAB", 
	      "pqiB", "pqiAB", "prfA", "kdsA", "prfB", "prfBlysS", "priB", "rpsF-rplI", 
	      "prlA", "spc", "prmA", "prmA", "proA", "proBA", "proB", "proBA", 
	      "proV", "proVWX", "proW", "proVWX", "proX", "proVWX", "pspA", "pspABCDE", 
	      "pspB", "pspABCDE", "pspC", "pspABCDE", "pspD", "pspABCDE", "pspE", "pspABCDE", 
	      "pta", "ackA-pta", "ptr", "ptr-recBD", "ptsH", "pts", "ptsI", "pts", 
	      "ptsN", "rpoN", "ptsO", "rpoN", "purD", "purHD", "purE", "purEK", 
	      "purF", "purF", "purH", "purHD", "purK", "purEK", "purM", "purMN", 
	      "purN", "purMN", "pyrB", "pyrBI", "pyrE", "rph-pyrE", "pyrF", "pyrF", 
	      "pyrH", "rpsB", "pyrI", "pyrBI", "queA", "secD", "rbfA", "rbfAtruB", 
	      "rbsA", "rbs", "rbsB", "rbs", "rbsC", "rbs", "rbsD", "rbs", 
	      "rbsK", "rbs", "recB", "ptr-recBD", "recD", "ptr-recBD", "recF", "dnaA", 
	      "recG", "spoT", "recO", "rnc", "recR", "recR", "relA", "relA", 
	      "rfaB", "rfa", "rfaG", "rfa", "rfaI", "rfa", "rfaJ", "rfa", 
	      "rfaP", "rfa", "rfaQ", "rfa", "rfaS", "rfa", "rfbA", "rfb", 
	      "rfbB", "rfb", "rfbC", "rfb", "rfbD", "rfb", "rfbX", "rfb", 
	      "rfc", "rfb", "rhaA", "rhaBAD", "rhaB", "rhaBAD", "rhaD", "rhaBAD", 
	      "rnc", "rnc", "rnhB", "lpx", "rnpA", "rpmH", "rpe", "dam", 
	      "rph", "rph-pyrE", "rpiA", "serA", "rplA", "L11", "rplB", "S10", 
	      "rplC", "S10", "rplD", "S10", "rplE", "spc", "rplF", "spc", 
	      "rplI", "rpsF-rplI", "rplJ", "beta", "rplK", "L11", "rplL", "beta", 
	      "rplM", "rplMrpsI", "rplN", "spc", "rplO", "spc", "rplP", "S10", 
	      "rplQ", "alpha", "rplR", "spc", "rplS", "trmD", "rplU", "rplUrpmA", 
	      "rplV", "S10", "rplW", "S10", "rplX", "spc", "rpmA", "rplUrpmA", 
	      "rpmC", "S10", "rpmD", "spc", "rpmF", "rpmF", "rpmH", "rpmH", 
	      "rpmJ", "spc", "rpoA", "alpha", "rpoB", "beta", "rpoC", "beta", 
	      "rpoD", "rpsU-dnaG-rpoD", "rpoN", "rpoN", "rpoZ", "spoT", "rpsA", "rpsA", 
	      "rpsB", "rpsB", "rpsC", "S10", "rpsD", "alpha", "rpsE", "spc", 
	      "rpsF", "rpsF-rplI", "rpsG", "str", "rpsH", "spc", "rpsI", "rplMrpsI", 
	      "rpsJ", "S10", "rpsK", "alpha", "rpsL", "str", "rpsM", "alpha", 
	      "rpsN", "spc", "rpsO", "rpsO-pnp", "rpsP", "trmD", "rpsQ", "S10", 
	      "rpsR", "rpsF-rplI", "rpsS", "S10", "rpsU", "rpsU-dnaG-rpoD", "rstA", "rst", 
	      "rstB", "rst", "ruvA", "ruvAB", "ruvB", "ruvAB", "sapA", "sap", 
	      "sapB", "sap", "sapC", "sap", "sapD", "sap", "sapF", "sap", 
	      "sdaB", "sdaCB", "sdaC", "sdaCB", "sdhA", "sdhCDAB", "sdhB", "sdhCDAB", 
	      "sdhC", "sdhCDAB", "sdhD", "sdhCDAB", "secD", "secD", "secE", "secE-nusG", 
	      "secF", "secD", "serA", "serA", "serB", "serBsms", "sms", "serBsms", 
	      "smtA", "smtAmukFEB", "speD", "speED", "speE", "speED", "speF", "speFpotE", 
	      "spoT", "spoT", "spoU", "spoT", "srlB", "srlABD", "srlD", "srlABD", 
	      "srlR", "srlABD", "sspA", "sspAB", "sspB", "sspAB", "sucA", "sucABCD", 
	      "sucB", "sucABCD", "sucC", "sucABCD", "sucD", "sucABCD", "surA", "surA-pdxA-ksgA-apaGH", 
	      "tap", "cheRBYZ", "tar", "cheRBYZ", "tdcA", "tdc", "tdcB", "tdc", 
	      "tdcC", "tdc", "tdh", "tdh", "tehA", "tehAB", "tehB", "tehAB", 
	      "tgt", "secD", "thiC", "thiCEFGH", "thiE", "thiCEFGH", "thiF", "thiCEFGH", 
	      "thiG", "thiCEFGH", "thiH", "thiCEFGH", "thrA", "thr", "thrB", "thr", 
	      "thrC", "thr", "tnaA", "tnaAB", "tnaB", "tnaAB", "tolA", "tolQRA", 
	      "tolB", "tolQRA", "tolQ", "tolQRA", "tolR", "tolQRA", "torA", "torCAD", 
	      "torC", "torCAD", "torD", "torCAD", "treB", "treBC", "treC", "treBC", 
	      "trmD", "trmD", "trpA", "trp", "trpB", "trp", "trpC", "trp", 
	      "trpD", "trp", "trpE", "trp", "trpS", "dam", "truA", "hisT", 
	      "truB", "rbfAtruB", "tsf", "rpsB", "ttdA", "ttdAB", "ttdB", "ttdAB", 
	      "ttk", "dfp-dut", "tufA", "str", "tyrA", "tyr", "tyrS", "pdxH-tyrS", 
	      "ubiA", "ubiCA", "ubiC", "ubiCA", "ubiX", "purF", "ugpA", "ugpBAECQ", 
	      "ugpB", "ugpBAECQ", "ugpC", "ugpBAECQ", "ugpE", "ugpBAECQ", "ugpQ", "ugpBAECQ", 
	      "uhpA", "uhp", "uhpB", "uhp", "uhpC", "uhp", "uhpT", "uhp", 
	      "uidA", "uidABC", "uidB", "uidABC", "umuC", "umuDC", "umuD", "umuDC", 
	      "upp", "upp-uraA", "uraA", "upp-uraA", "usg", "hisT", "uvrC", "uvrYC", 
	      "uvrY", "uvrYC", "uxaA", "uxaCA", "uxaC", "uxaCA", "uxuA", "uxuAB", 
	      "uxuB", "uxuAB", "vsr", "dcm-vsr", "xapA", "xapAB", "xapB", "xapAB", 
	      "xylF", "xylFGH", "xylG", "xylFGH", "xylH", "xylFGH", "xylR", "xylFGH", 
	      "yaaC", "ileS-lsp", "yajC", "secD", "ybaB", "recR", "yceD", "rpmF", 
	      "ychA", "kdsA", "yciH", "pyrF", "ydfA", "dicB", "ydfB", "dicB", 
	      "ydfC", "dicB", "ydfD", "dicB", "ydfE", "dicB", "yefE", "rfb", 
	      "yefG", "rfb", "yefH", "rfb", "yefI", "rfb", "yegA", "dcd", 
	      "yfbB", "menFDBCE", "yfjA", "trmD", "ygjI", "ebgAC", "yhbC", "nusA", 
	      "yhbG", "rpoN", "yhbH", "rpoN", "yhbN", "rpoN", "yhdG", "fis", 
	      "yhdJ", "fis", "yhfG", "fic-pabA", "yjeE", "amiB", "yjeF", "amiB", 
         );
       
       foreach my $cds ($gb->cds()){
	   my $gene = $gb->{$cds}->{gene};
	   if (length($op{$gene})){
	       $gb->{$cds}->{operon} = $op{$gene};
	   }
       }

       msg_error("Operon data loaded.\n");
   }else{
       msg_error("No Operon data for this species.\n\n");
   }

    return 1;
}




sub DESTROY {
    my $self = shift;
}




1;
__END__
# Below is the stub of documentation for your module. You better edit it!

=head1 NAME

G::Seq::Operon - Perl extension for blah blah blah

=head1 SYNOPSIS

  use G::Seq::Operon;
  blah blah blah

=head1 DESCRIPTION

Stub documentation for G::Seq::Operon was created by h2xs. It looks like the
author of the extension was negligent enough to leave the stub
unedited.

Blah blah blah.

=head1 AUTHOR

A. U. Thor, a.u.thor@a.galaxy.far.far.away

=head1 SEE ALSO

perl(1).

=cut

