#!/usr/bin/env perl

#:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
# This file is part of G-language Genome Analysis Environment package
#
#     Copyright (C) 2001 - 2002 Keio University
#:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
# 
#   $Id: ReL8.pm,v 1.1.1.1 2002/04/02 20:25:44 gaou Exp $
#
# G-language GAE is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# G-language GAE is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public
# License along with G-language GAE -- see the file COPYING.
# If not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
# 
#END_HEADER
#
# written by Tatekimi Matsuzaki <tero@g-language.org> at
# G-language Project, Institute for Advanced Biosciences, Keio University.
#

package G::System::ReL8;

use SubOpt;
use G::Tools::Fasta;
use G::Tools::SIM4;
use G::Tools::Cap3;
use G::Tools::Blast;
use G::Tools::PBS;
use G::Messenger;

use strict("vars");
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

require Exporter;

@ISA = qw(Exporter AutoLoader);

@EXPORT = qw(
	     redundancy
	     redundancy_fasta
	     redundancy_sim4
	     redundancy_cap3
             cluster
	     cap3_parse
	     blast_parse
	     sim4_parse
	     fasta_parse
	     file_maker  
	     Totals
             output_maker
);
$VERSION = '0.01';

#::::::::::::::::::::::::::::::
#        Methods Start
#::::::::::::::::::::::::::::::

sub new{
    my $pkg = shift;
    my $filename = shift;
    my $option = shift;
    my $this;
    return ($this);
}


sub file_maker{
    
    &opt_default(directory_name=>"/tmp/ReL8/",sdirectory_name=>time());
    
    my @args=&opt_get(@_);
    my $gb = shift @args;
    my $directory_name=&opt_val("directory_name");
    my $sdirectory_name=&opt_val("sdirectory_name");
    my @filename=();
    my $id_number=0;
    
    mkdir($directory_name,0777)if(opendir(DIR,$directory_name) != 1);
    mkdir($directory_name.$sdirectory_name,0777);
    chdir($directory_name.$sdirectory_name);

    open(FILE2,'>master.seq');
    open(FILE3,'>ID_list.txt');

    do{
	$filename[$id_number]=$gb->{LOCUS}->{id};
	print FILE3 $id_number."       ".$gb->{LOCUS}->{id}."\n";
	open(FILE,'>'.$id_number.'.seq');
	print FILE ">$id_number"._.length($gb->{SEQ})."\n".uc($gb->{SEQ})."\n";
	print FILE2 ">$id_number"._.length($gb->{SEQ})."\n".uc($gb->{SEQ})."\n";
	close(FILE);
	$id_number++;
    }while($gb->next_locus("no msg"));
    $gb->rewind_genome();
    $gb->next_locus("no msg");
    close(FILE2);
    close(FILE3);
    return (@filename);
}

sub Totals{
    &opt_default(style=>"Remove",output=>"STDOUT");
    my @args = &opt_get(@_);
    my $tmp = shift @args;
    my $style = &opt_val("style");
    my %Re_list =%$tmp;
    my @list=();
    my %tmp2=();
    my $best;
    my $best_name;
    my $moin;

    my $hohoho;
    
    $best = 1 if($style eq "Remove");

   
    foreach $moin (keys %Re_list){
	my @tmp2 = @{$Re_list{$moin}};
	$best = 1 if($style eq "Remove");
	$best_name=();
	foreach (@tmp2){
	    if(/(\w+)\_(\d+)/){
		if($style eq "Remove"){
		   if($best < $2){
		       $tmp2{$best_name}++ if($best_name);
		       $best = $2;
		       $best_name = $1;
		   }else{
		       $tmp2{$1}++ if($best_name);
		   }
	       }elsif($style eq "Include"){
		   $tmp2{$1}++ if($best_name);
	       }
	    }
	}
    }
    @list = keys %tmp2;
    foreach $hohoho(@list){
	msg_send($hohoho,"\n");
    }
    return (@list);
}

sub output_maker{
    &opt_default(output=>"STDOUT",file_name=>"default.gbk");
    my @args = &opt_get(@_);
    my $gb = shift @args;
    my $Re_name = shift @args;  
    my $output =  &opt_val("output"); 
    my $file_name = &opt_val("file_name");
    my $flag=0;

    do{
	$flag=0;
	foreach(@$Re_name){ 
	    $flag=1 if($gb->{LOCUS}->{id} eq $_);    
	} 
	$gb->make_gb($file_name, "attach")if($flag==0);
    }while($gb->next_locus("no msg"));
}

sub cluster{
   &opt_default(output=>"STDOUT");
   my @args = &opt_get(@_);
   my $tmp = shift @args;
   my %Re_list =%$tmp;

   my @list = keys %Re_list;
   my $list_name1;
   my $list_name2;
   my $list_name3;
   my $list_name4;

   my @sub_class=();
   my %class=();

   my $m=0;
   my $tmp=();

   foreach $list_name1 (@list){
       open(FILE,'>'.$list_name1.'-class.seq');
       foreach $list_name2 (@{$Re_list{$list_name1}}){
	   push(@sub_class,$list_name2);
	   open(FILE2,$list_name2.'.seq');
	   
	   while(<FILE2>){
	       print FILE $_;
	   }
	   
	   close(FILE2);
	   
	   $m=0;
	   
	   foreach $tmp (@list){
	       $m++;
	       splice(@list,$m,1)if($tmp eq $list_name2);
	   }
       }
       $class{$list_name1}=[@sub_class];
       close(FILE);
   }

   foreach $list_name3 (keys %class){
       foreach $list_name4 (@{$class{$list_name3}}){
	   _sim4($list_name4.".seq",$list_name3.'-class.seq',-output=>$list_name4."-".$list_name3."-class.sim");
       }
   }  
}

sub blast_parse{
    &opt_default(output=>"STDOUT",Identities=>"NULL",db_file=>"master.seq");
    my @args=opt_get(@_);
    my $file_number = shift;
    my $Identities = &opt_val("Identities");
    my $db_file = &opt_val("db_file");
    my $i=0;
    my %Re_list;
    my $flag=0;
    my $tmp = 0;
    my $m=0;
    my %score=();
    my @R=();
    
    while( $i < $file_number){
	$score{bunsi}=0;
	$score{bunbo}=0;
	$flag=0;
	open(FILE,$i.".bla");
	while(<FILE>){
	    if(/^Sequences producing significant alignments\:/){
		$flag=1;
	    }elsif(/^(\d+)\_(\d+) +\d+ +(\S+)/ && $flag == 1){
		push(@R,$1."_".$2);
		msg_send($_);
	    }elsif(/^\>(\S+)/){
		if($score{bunbo}!=0){
		    if($Identities ne "NULL"){
			$m=0;
			if($score{bunsi}/$score{bunbo}*100 < $Identities){
			    foreach $tmp (@R){
				$m++;
				splice(@R,$m,1)if($tmp eq $1);
			    }
			}
		    }
		}
		$score{bunsi}=0;
		$score{bunbo}=0;   
		$flag++;
		$tmp=$1;
	    }elsif(/^ Identities \= (\d+)\/(\d+) +\((\d+)\%\)/){
		$score{bunsi}=$score{bunsi}+$1;
		$score{bunbo}=$score{bunbo}+$2;        
	    }elsif(/^  Database\: +$db_file/ && $flag >1){
		if($score{bunbo}!=0){
		    if($Identities ne "NULL"){
			$m=0;
			if($score{bunsi}/$score{bunbo}*100 < $Identities){
			    foreach $tmp (@R){
				$m++;
				splice(@R,$m,1)if($tmp eq $1);
			    }
			}
		    }
		}
		msg_send($i,"  ",@R,"\n");
		$Re_list{$i}= [@R];
		@R=();
		last;
	    }
	}
	$i++;
    }
    return (%Re_list);   
}

sub fasta_parse{
    &opt_default(output=>"STDOUT",Identities=>"NULL");
    my @args=opt_get(@_);
    my $file_number = shift;
    my $Identities = &opt_val("Identities");
    my $i=0;
    my %Re_list;
    my $flag=0;
    my @R=();
    
    while($i< $file_number){
	$flag=0;
	open(FILE,$i.".fst");
	while(<FILE>){
	    if(/The best scores are\:/){
		$flag=1;
	    }elsif(/(\w+)\_(\d+) +\(\d+\) +\[f\] +\d+ +\d+ +(\S+)/ && $flag == 1){
		push(@R,$1."_".$2);
	    }elsif(/^\>\>\w+/ & $flag == 1){
		$Re_list{$i}= [@R];
		@R=();
		last;
	    }
	}
	$i++;
    }
    return (%Re_list);
}

sub cap3_parse{

}

sub sim4_parse{ 
    &opt_default(value=>"0.99",output=>"STDOUT");
    my $file_number = shift;
    my @args=opt_get(@_);
    my $value = &opt_val("value");
    my $flag;   
    my $seq1_name;
    my $seq2_name;
    my $seq1_leng=1;
    my $seq2_leng;
    my $score=0;
    my @R=();
    my $name=();
    my $i=0;
    my %Re_list=();   
    
    while($i < $file_number){
       	open(FILE,$i.".sim");
	$flag = 1;
	while(<FILE>){
	    if(/^seq1 +\= +(\w+)\.seq\, +(\d+) +bp/){
		if($score > $value && $flag > 1){
		    push(@R,$seq2_name."_".$seq2_leng);
		}
		elsif($score > $value && $flag == 1){
		    push(@R,$seq1_name."_".$seq1_leng);
		}
		$flag=1;
		$seq1_name=$1;
		$seq1_leng=$2;
		$score = 0;
	    }elsif(/^seq2 +\= +\w+\.seq\ +\((\w+)\_\d+\)\, +(\d+) +bp/){    
		$seq2_name=$1;
		$seq2_leng=$2;
	    }elsif(/\(complement\)/){
		$flag=0;
	    }elsif(/^(\d+)\-(\d+) +\(\d+\-\d+\) +(\d+)\%/ && $flag >0){
		if($seq1_leng < $seq2_leng){
		    $score=$score+(($2-$1+1)/100*$3/$seq1_leng);
		}else{
		    $score=$score+(($2-$1+1)/100*$3/$seq2_leng);
		}
		$flag++;
	    } 
	}
	if($score > $value && $flag > 1){
	    push(@R,$seq2_name."_".$seq2_leng);
	}	
	$Re_list{$i} = [@R];
	@R=();
	$i++;
    }
    return(%Re_list);
}

sub redundancy{
    &opt_default(qsub=>"off",analysis_method=>"fasta",directory_name=>"/tmp/ReL8/",sdirectory_name=>time(),value=>"1e-50",output=>"default.gbk",clustering=>"ON",identities=>"NULL");
   
    my @args=&opt_get(@_);
    my $gb = shift @args;  
    my $qsub=opt_val("qsub");
    my $analysis_method = &opt_val("analysis_method");
    my $directory_name = &opt_val("directory_name");
    my $sdirectory_name = &opt_val("sdirectory_name");
    my $output=&opt_val("output");
    my $value=&opt_val("value");
    my $clustering=&opt_val("clustering");
    my $identities=&opt_val("identities");
    my @filename=();
    my $i=0;
    my $change_name;
    my @file_list=();
    my %tmp=();
    my @tmp2=();
    
    
    @filename = file_maker($gb,-sdirectory_name=>$sdirectory_name,-directory_name=>$directory_name);
    
    
    _formatdb("master.seq",-p=>"F",-o=>"T")if( $analysis_method eq "blast");
    while($i < $#filename + 1){
	msg_send(".");
	_blast("master.seq","$i".".seq",-p=>"blastn",-o=>$i.".bla",-e=>$value)if( $analysis_method eq "blast");
	_fasta('-Q','-n',-O=>$i.".fst",-E=>$value,$i.".seq","master.seq")if( $analysis_method eq "fasta");
	_sim4($i.".seq",'master.seq',-output=>$i.".sim")if( $analysis_method eq "sim4");
#	_cap3($i.".seq",'master.seq',-output=>$i.".cap",-qsub=$qsub)if( $analysis_method eq "cap3");
	$i++;
    }
    
    %tmp = fasta_parse($#filename+1)if( $analysis_method eq "fasta");
    
    %tmp = sim4_parse($#filename+1,-value=>$value)if( $analysis_method eq "sim4");
    
    %tmp = blast_parse($#filename+1,-value=>$value,-identities=>"90")if( $analysis_method eq "blast");

    %tmp = cap3_parse($#filename+1,-value=>$value,-qsub=>$qsub)if( $analysis_method eq "cap3");
    @tmp2 = Totals(\%tmp);
    foreach $change_name (@tmp2){ 
	push(@file_list,$filename[$change_name]);
    }
    
    output_maker($gb,\@file_list,-file_name=>$output);
    msg_send("Finish !! output file is ",$output,"\n");
    
}





sub redundancy_fasta{
    &opt_default(directory_name=>"/tmp/ReL8/",sdirectory_name=>time(),value=>"1e-50",output=>"~/asimo/default.gbk",filename=>"redundancy_fasta.lst");
   
    my @args=&opt_get(@_);
    my $gb = shift @args;  
    my $directory_name=&opt_val("directory_name");
    my $sdirectory_name=&opt_val("sdirectory_name");
    my $output=opt_val("output");
    my $filename=opt_val("filename");
    my $value=opt_val("value");
    my @filename=();
    my %tmp=();
    my @tmp2=();

    @filename = file_maker($gb,-sdirectory_name=>$sdirectory_name,-directory_name=>$directory_name);
   
    foreach(@filename){
       _fasta('-Q','-n',-O=>$_.".fst",-E=>$value,$_.".seq","master.seq");
	
    }
    %tmp = fasta_parse(\@filename);
    @tmp2 = Totals(\%tmp);
    output_maker($gb,\@tmp2,-file_name=>$output);
    msg_send("Finish !! output file is ",$output,"\n");
}

sub redundancy_sim4{
    &opt_default(directory_name=>"/tmp/ReL8/",sdirectory_name=>time(),value=>0.98,output=>"~/asimo/default.gbk",filename=>"redundancy_sim4.lst" );
    
    my @args=&opt_get(@_);
    my $gb = shift @args;
    my $directory_name=&opt_val("directory_name");
    my $sdirectory_name=&opt_val("sdirectory_name");
    my $output=opt_val("output");
    my $filename=opt_val("filename");
    my $value=opt_val("value");
    my @filename=();
    my %tmp=();
    my @tmp2=();  
 
    chdir($directory_name.$sdirectory_name);

    @filename = &file_maker($gb,-sdirectory_name=>$sdirectory_name,-directory_name=>$directory_name);

    foreach(@filename){
	msg_send(".");
	_sim4($_.".seq",'master.seq',-output=>$_.".sim");
    }
    %tmp = sim4_parse(\@filename,-value=>$value,);
    @tmp2 = Totals(\%tmp);
    

    &output_maker($gb,\@tmp2,-file_name=>$output);
    msg_send("Finish !! output file is ",$output,"\n");
}

sub redundancy_cap3{
    &opt_default(qsub=>"off",directory_name=>"/tmp/ReL8/",sdirectory_name=>time(),value=>0.98,output=>"~/asimo/default.gbk",filename=>"redundancy_cap3.lst" );
    
    my @args=&opt_get(@_);
    my $gb = shift @args;
    my $qsub=opt_val("qsub");
    my $directory_name=&opt_val("directory_name");
    my $sdirectory_name=&opt_val("sdirectory_name");
    my $output=opt_val("output");
    my $filename=opt_val("filename");
    my $value=opt_val("value");
    my @filename=();
    my %tmp=();
    my @tmp2=();  
 
    chdir($directory_name.$sdirectory_name);

    @filename = &file_maker($gb,-sdirectory_name=>$sdirectory_name,-directory_name=>$directory_name);

    foreach(@filename){
	msg_send(".");
	_cap3($_.".seq",'master.seq',-output=>$_.".cap",-qsub=>$qsub);
    }
    %tmp = cap3_parse(\@filename,-value=>$value,);
    @tmp2 = Totals(\%tmp);
    

    &output_maker($gb,\@tmp2,-file_name=>$output);
    msg_send("Finish !! output file is ",$output,"\n");
}


sub DESTROY {
    my $self = shift;
}

1;
__END__
















