#!/usr/bin/env perl

#:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
# This file is part of G-language Genome Analysis Environment package
#
#     Copyright (C) 2001 - 2002 Keio University
#:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
# 
#   $Id: Blast.pm,v 1.1.1.1 2002/04/02 20:25:44 gaou Exp $
#
# G-language GAE is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
# 
# G-language GAE is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public
# License along with G-language GAE -- see the file COPYING.
# If not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
# 
#END_HEADER
#

package G::Tools::Blast;

use SubOpt;
use G::Messenger;
use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

require Exporter;

@ISA = qw(Exporter AutoLoader);
# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.
@EXPORT = qw(
	     _blast_tp_finder
	     _blast
	     _formatdb
);
$VERSION = '0.01';

#::::::::::::::::::::::::::::::
#        Methods Start
#::::::::::::::::::::::::::::::
sub new{
    my $pkg = shift;
    my $filename = shift;
    my $option = shift;
    my $this;

    return $this;
}


sub _blast{  
    &opt_default(p=>'blastn',qr=>'off',input=>"file");
    my @args=opt_get(@_);

    my $qr=&opt_val("qr");
    my $input=&opt_val("input");
    my $seq;
    my @param;
    my $param;
    my %opt;
    my @tmp;
    my $num;

    $opt{d}=shift @args;
    if($input eq 'seq'){
	$seq=shift @args;
	opendir(DIR,'/tmp');
	@tmp=readdir(DIR);
	$num=$#tmp+1+time;
	@tmp=keys(%$seq);
	close(DIR);
	open(FILE,'>/tmp/blast_'.$num.'.seq');
        print FILE ">$tmp[0]\n";
        print FILE $$seq{$tmp[0]},"\n";
	close(FILE);
	$opt{i}='/tmp/blast_'.$num.'.seq'; 
    }
    else{
	$opt{i}=shift @args;
    }

    $opt{p}=opt_val("p");
    $opt{e}=opt_val("e");
    $opt{m}=opt_val("m");
    $opt{o}=opt_val("o");
    $opt{F}=opt_val("F");
    $opt{G}=opt_val("G");
    $opt{E}=opt_val("E");
    $opt{X}=opt_val("X");
    $opt{I}=opt_val("I");
    $opt{q}=opt_val("q");
    $opt{r}=opt_val("r");
    $opt{v}=opt_val("v");
    $opt{b}=opt_val("b");
    $opt{f}=opt_val("f");
    $opt{g}=opt_val("g");
    $opt{Q}=opt_val("Q");
    $opt{D}=opt_val("D");
    $opt{a}=opt_val("a");
    $opt{J}=opt_val("J");
    $opt{M}=opt_val("M");
    $opt{W}=opt_val("W");
    $opt{z}=opt_val("z");
    $opt{K}=opt_val("K");
    $opt{P}=opt_val("P");
    $opt{Y}=opt_val("Y");
    $opt{S}=opt_val("S");
    $opt{T}=opt_val("T");
    $opt{U}=opt_val("U");
    $opt{y}=opt_val("y");
    $opt{Z}=opt_val("Z");
    $opt{n}=opt_val("n");
    $opt{A}=opt_val("A");
    $opt{w}=opt_val("w");
    $opt{t}=opt_val("t");
    $opt{L}=opt_val("L");
    $opt{O}=opt_val("O");
    $opt{l}=opt_val("l");
    $opt{R}=opt_val("R");

    foreach(sort keys(%opt)){
	next if($opt{$_} eq '');
	push(@param,'-'.$_);
	push(@param,$opt{$_});
    }
    $param=join(' ',@param);

    system('blastall',@param) if($qr eq "off");
    system('qr',"blastall $param") if($qr eq "on");

    unlink('/tmp/blast_'.$num.'.seq') if($input eq 'seq' && $qr ne 'on');
    return $param;
}


sub _formatdb{
    &opt_default(p=>'F',o=>'T');
    my @args=opt_get(@_);

    my $file=shift @args;
    my @param;
    my %opt;
    $opt{p}=opt_val('p');
    $opt{o}=opt_val('o');
    $opt{t}=opt_val('t');
    $opt{l}=opt_val('l');
    $opt{a}=opt_val('a');
    $opt{b}=opt_val('b');
    $opt{e}=opt_val('e');
    $opt{n}=opt_val('n');
    $opt{v}=opt_val('v');
    $opt{s}=opt_val('s');
    $opt{V}=opt_val('V');
    $opt{A}=opt_val('A');

    foreach(sort keys(%opt)){
	next if($opt{$_} eq '');
	push(@param,'-'.$_);
	push(@param,$opt{$_});
    }

    system('formatdb','-i',"$file",@param);

    return '-i '."$file ".join(' ',@param);
}


sub _blast_tp_finder{
    my $file=shift;
    my @id_query;
    my $query_name;
    my @query;
    my @query_num;
    my $s1;
    my @query_num_sort;
    my $query_start;
    my $query_end;
    my @sbject_num;
    my @sbject_num_sort;
    my $sbject_start;
    my $sbject_end;
    my $idname;
    my @strand;
    my @sbject;
    my @infile;
    my @score;
    my $evalue;
    
    
    &msg_send("\nEVALUE-->QUERY-->DATABASE-->QUERY RANGE-->DATABASE RANGE-->STRAND\n---------------------------------------------------------------------------\n");
    open(FILE,"$file");
    while(<FILE>){
	if(/Query=/){
	    @id_query=split(/\s/,$_);
	    $_=~s/Query= //;
	    $_=~tr/\n//d;
	    $query_name=$_;    
	}
	if(/Query:/){
	    @query=split(/[\s]+/,$_);
	    push(@query_num,$query[1]);
	    push(@query_num,$query[3]);
	    $s1=1;
	}
	if(/Score / || />/ || /Lambda/){
	    &msg_send("$evalue");
	    @score=split(/Expect/,$_);
	    $evalue=$score[1];
	    $evalue=~tr/=//d;
	    $evalue=~tr/\n//d;
	    @query_num_sort=sort {$b<=>$a} @query_num;
	    $query_start=pop @query_num_sort;
	    $query_end=shift @query_num_sort;
	    @sbject_num_sort=sort {$b<=>$a} @sbject_num;
	    $sbject_start=pop @sbject_num_sort;
	    $sbject_end=shift @sbject_num_sort;
	    if($query_start!=""){
		&msg_send("\t$query_name\t$query_start>>$query_end   \t$idname\t$sbject_start>>$sbject_end   \t$strand[5]\n");
	    }
	    @query=();
	    @query_num=();
	    @sbject=();
	    @sbject_num=();
	    $s1=0;
	    
	}
	if(/>/){
	    $idname=$_;
	    $idname=~tr/>//d;
	    $idname=~tr/\n//d;
	}
	if($s1==0){
	    if(/Strand/){
		@strand=split(/\s/,$_);
	    }
	}
	if($s1==1){
	    if(/Sbjct:/){
		@sbject=split(/\s+/,$_);
		push(@sbject_num,$sbject[1]);
		push(@sbject_num,$sbject[3]);
	    }
	}
    }
    close(FILE);
}


sub DESTROY {
    my $self = shift;
}

1;
__END__
# Below is the stub of documentation for your module. You better edit it!

=head1 NAME

G::Tools::H2v - Perl extension for blah blah blah

=head1 SYNOPSIS

  use G::Tools::Blast;
  blah blah blah

=head1 DESCRIPTION

Stub documentation for G::Tools::Blast was created by h2xs. It looks like the
author of the extension was negligent enough to leave the stub
unedited.

Blah blah blah.

=head1 AUTHOR

A. U. Thor, a.u.thor@a.galaxy.far.far.away

=head1 SEE ALSO

perl(1).

=cut
